@@ -476,12 +476,23 @@ fo_context_util_spaces_resolve (FoContext *context,
 {
   GError *tmp_error = NULL;
   FoDatatype *space;
-  FoDatatype *shorthand, *minimum, *optimum, *maximum, *precedence, *condity;
+  FoDatatype *shorthand;
+  FoDatatype *minimum;
+  FoDatatype *optimum;
+  FoDatatype *maximum;
+  FoDatatype *precedence;
+  FoDatatype *condity;
   gdouble hundred_percent;
 
   g_return_if_fail (context != NULL);
   g_return_if_fail (FO_IS_CONTEXT (context));
 
+  /* Reference area is same for resolving all space properties. */
+  hundred_percent =
+    reference_area != NULL ?
+    fo_area_get_child_available_bpdim (reference_area): 0.0;
+
+  /* space-before */
   shorthand =
     context->space_before != NULL ?
     fo_property_get_value (context->space_before) : NULL;
@@ -500,9 +511,6 @@ fo_context_util_spaces_resolve (FoContext *context,
   condity =
     context->space_before_condity != NULL ?
     fo_property_get_value (context->space_before_condity) : NULL;
-  hundred_percent =
-    reference_area != NULL ?
-    fo_area_get_child_available_bpdim (reference_area): 0.0;
 
   space = fo_space_resolve (shorthand,
 			    minimum,
@@ -520,11 +528,15 @@ fo_context_util_spaces_resolve (FoContext *context,
 						   space,
 						   NULL);
       fo_context_set_space_before (context, new_space_before);
-      g_object_unref (space);
       g_object_unref (new_space_before);
     }
   else
-    fo_context_set_space_before (context, NULL);
+    {
+      fo_context_set_space_before (context, NULL);
+    }
+
+  g_object_unref (space);
+  space = NULL;
 
   fo_context_set_space_before_minimum (context, NULL);
   fo_context_set_space_before_optimum (context, NULL);
@@ -532,6 +544,7 @@ fo_context_util_spaces_resolve (FoContext *context,
   fo_context_set_space_before_precedence (context, NULL);
   fo_context_set_space_before_condity (context, NULL);
 
+  /* space-after */
   shorthand =
     context->space_after ?
     fo_property_get_value (context->space_after) : NULL;
@@ -557,7 +570,7 @@ fo_context_util_spaces_resolve (FoContext *context,
 			    maximum,
 			    precedence,
 			    condity,
-			    reference_area ? fo_area_get_child_available_bpdim (reference_area): 0.0,
+			    hundred_percent,
 			    &tmp_error);
 
   if (space != NULL)
@@ -567,11 +580,15 @@ fo_context_util_spaces_resolve (FoContext *context,
 						  space,
 						  NULL);
       fo_context_set_space_after (context, new_space_after);
-      g_object_unref (space);
       g_object_unref (new_space_after);
     }
   else
-    fo_context_set_space_after (context, NULL);
+    {
+      fo_context_set_space_after (context, NULL);
+    }
+
+  g_object_unref (space);
+  space = NULL;
 
   fo_context_set_space_after_minimum (context, NULL);
   fo_context_set_space_after_optimum (context, NULL);
@@ -579,6 +596,7 @@ fo_context_util_spaces_resolve (FoContext *context,
   fo_context_set_space_after_precedence (context, NULL);
   fo_context_set_space_after_condity (context, NULL);
 
+  /* space-start */
   shorthand =
     context->space_start ?
     fo_property_get_value (context->space_start) : NULL;
@@ -604,7 +622,7 @@ fo_context_util_spaces_resolve (FoContext *context,
 			    maximum,
 			    precedence,
 			    condity,
-			    reference_area ? fo_area_get_child_available_bpdim (reference_area): 0.0,
+			    hundred_percent,
 			    &tmp_error);
 
   if (space != NULL)
@@ -614,12 +632,17 @@ fo_context_util_spaces_resolve (FoContext *context,
 						  space,
 						  NULL);
       fo_context_set_space_start (context, new_space_start);
-      g_object_unref (space);
       g_object_unref (new_space_start);
     }
   else
-    fo_context_set_space_start (context, NULL);
+    {
+      fo_context_set_space_start (context, NULL);
+    }
 
+  g_object_unref (space);
+  space = NULL;
+
+  /* space-end */
   shorthand =
     context->space_end ?
     fo_property_get_value (context->space_end) : NULL;
@@ -645,7 +668,7 @@ fo_context_util_spaces_resolve (FoContext *context,
 			    maximum,
 			    precedence,
 			    condity,
-			    reference_area ? fo_area_get_child_available_ipdim (reference_area): 0.0,
+			    hundred_percent,
 			    &tmp_error);
 
   if (space != NULL)
@@ -655,12 +678,15 @@ fo_context_util_spaces_resolve (FoContext *context,
 						space,
 						NULL);
       fo_context_set_space_end (context, new_space_end);
-      g_object_unref (space);
       g_object_unref (new_space_end);
     }
   else
-    fo_context_set_space_end (context, NULL);
+    {
+      fo_context_set_space_end (context, NULL);
+    }
 
+  g_object_unref (space);
+  space = NULL;
 }
 
 /**
