@@ -2,7 +2,7 @@
  * fo-doc-cairo.c: libfo output document based on Cairo.
  *
  * Copyright (C) 2001-2006 Sun Microsystems
- * Copyright (C) 2007 Menteith Consulting Ltd
+ * Copyright (C) 2007-2008 Menteith Consulting Ltd
  *
  * See COPYING for the status of this software.
  */
@@ -23,11 +23,20 @@
 #include "datatype/fo-color.h"
 #include <string.h>
 
+/**
+ * SECTION:fo-doc-cairo
+ * @short_description: Cairo backend
+ *
+ * Cairo backend.
+ */
+
 static void fo_doc_cairo_init          (FoDocCairo      *object);
 static void fo_doc_cairo_base_init     (FoDocCairoClass *klass);
 static void fo_doc_cairo_class_init    (FoDocCairoClass *klass);
 static void fo_doc_cairo_finalize      (GObject         *object);
 
+static const LibfoVersionInfo * _version_info ();
+
 static FoLayout *    fo_doc_cairo_get_new_layout     (FoDoc        *fo_doc);
 
 static void          fo_doc_cairo_begin_page         (FoDoc        *fo_doc,
@@ -101,6 +110,17 @@ static void 	     fo_doc_cairo_render_layout       (FoDoc       *fo_doc,
 						       gdouble      y);
 static gpointer parent_class;
 
+static LibfoVersionInfo version_info =
+  {
+    LIBFO_MODULE_BACKEND,
+    "cairo",
+    "FoDocCairo",
+    CAIRO_VERSION,
+    CAIRO_VERSION_STRING,
+    0,
+    NULL
+  };
+
 /**
  * fo_doc_cairo_error_quark:
  * 
@@ -181,8 +201,19 @@ fo_doc_cairo_init (FoDocCairo *fo_doc_cairo)
 void
 fo_doc_cairo_base_init (FoDocCairoClass *klass)
 {
+  FoLibfoModuleClass *fo_libfo_module_class =
+    FO_LIBFO_MODULE_CLASS (klass);
   FoDocClass *fo_doc_class = FO_DOC_CLASS (klass);
 
+  fo_libfo_module_class->version        = cairo_version;
+  fo_libfo_module_class->version_string = cairo_version_string;
+  fo_libfo_module_class->version_info   = _version_info;
+
+  fo_doc_class->formats =
+    FO_FLAG_FORMAT_PDF |
+    FO_FLAG_FORMAT_POSTSCRIPT |
+    FO_FLAG_FORMAT_SVG;
+
   fo_doc_class->open_file           = fo_doc_cairo_open_file;
 
   fo_doc_class->get_new_layout      = fo_doc_cairo_get_new_layout;
@@ -264,6 +295,16 @@ fo_doc_cairo_new (void)
 			       NULL));
 }
 
+const LibfoVersionInfo *
+_version_info ()
+{
+  version_info.runtime = cairo_version ();
+  version_info.runtime_string = cairo_version_string ();
+
+  return &version_info;
+}
+
+
 /**
  * fo_doc_cairo_open_file:
  * @fo_doc:        #FoDoc.
@@ -298,7 +339,7 @@ fo_doc_cairo_open_file (FoDoc          *fo_doc,
   len = strlen (fo_doc_cairo->base_filename);
   switch (fo_doc_cairo->format)
     {
-    case FO_ENUM_FORMAT_AUTO:
+    case FO_FLAG_FORMAT_AUTO:
       if (g_ascii_strncasecmp (&(fo_doc_cairo->base_filename)[len-4], ".pdf", 4) == 0)
 	{
 	  fo_doc_cairo->surface_create = &cairo_pdf_surface_create;
@@ -319,13 +360,13 @@ fo_doc_cairo_open_file (FoDoc          *fo_doc,
 		       N_(fo_doc_error_messages[FO_DOC_ERROR_UNSUPPORTED_FORMAT]));
 	}
       break;
-    case FO_ENUM_FORMAT_PDF:
+    case FO_FLAG_FORMAT_PDF:
       fo_doc_cairo->surface_create = &cairo_pdf_surface_create;
       break;
-    case FO_ENUM_FORMAT_POSTSCRIPT:
+    case FO_FLAG_FORMAT_POSTSCRIPT:
       fo_doc_cairo->surface_create = &cairo_ps_surface_create;
       break;
-    case FO_ENUM_FORMAT_SVG:
+    case FO_FLAG_FORMAT_SVG:
       fo_doc_cairo->surface_create = &cairo_svg_surface_create;
       break;
     default:
@@ -1026,13 +1067,13 @@ fo_doc_cairo_place_image (FoDoc   *fo_doc,
   static const cairo_user_data_key_t key;
   int j;
 
-  /*cairo_translate (FO_DOC_CAIRO (fo_doc)->cr, 0, height * yscale * 72.0 / PIXELS_PER_INCH);*/
+  cairo_translate (FO_DOC_CAIRO (fo_doc)->cr,
+		   0,
+		   FO_DOC_CAIRO(fo_doc)->page_height);
   cairo_save (FO_DOC_CAIRO(fo_doc)->cr);
-  /*
   cairo_scale (FO_DOC_CAIRO (fo_doc)->cr,
 	       xscale * 72.0 / PIXELS_PER_INCH,
 	       yscale * 72.0 / PIXELS_PER_INCH);
-  */
   if (n_channels == 3)
     {
       format = CAIRO_FORMAT_RGB24;
@@ -1119,10 +1160,10 @@ fo_doc_cairo_place_image (FoDoc   *fo_doc,
 }
 
 void
-fo_doc_cairo_do_run_callbacks (cairo_t *cr,
-			    PangoLayoutRun    *run,
-			    gint               x, 
-			    gint               y)
+fo_doc_cairo_do_run_callbacks (cairo_t        *cr,
+			       PangoLayoutRun *run,
+			       gint            x, 
+			       gint            y)
 {
   GSList *extra_attrs_list = run->item->analysis.extra_attrs;
 
@@ -1150,7 +1191,7 @@ fo_doc_cairo_do_run_callbacks (cairo_t *cr,
 
 	  cairo_translate (cr,
 			   x / PANGO_SCALE,
-			   y / PANGO_SCALE);
+			   -y / PANGO_SCALE);
 
 	  g_closure_invoke (((GClosure *) libfo_pango_attr_callback_get_callback(attr)),
 			     NULL,
@@ -1165,10 +1206,10 @@ fo_doc_cairo_do_run_callbacks (cairo_t *cr,
 }
 
 void 
-fo_doc_cairo_do_line_callbacks (cairo_t *cr,
-			     PangoLayoutLine   *line,
-			     gint               x, 
-			     gint               y)
+fo_doc_cairo_do_line_callbacks (cairo_t         *cr,
+				PangoLayoutLine *line,
+				gint             x, 
+				gint             y)
 {
   GSList *run_list;
   PangoRectangle overall_rect;
@@ -1350,7 +1391,7 @@ fo_doc_cairo_render_layout (FoDoc   *fo_doc,
 
   cairo_move_to (FO_DOC_CAIRO (fo_doc)->cr,
 		 x,
-		 y);
+		 FO_DOC_CAIRO (fo_doc)->page_height - y);
   pango_cairo_show_layout (FO_DOC_CAIRO (fo_doc)->cr,
 			   fo_layout_get_pango_layout (fo_area_layout_get_layout (area_layout)));
 
