@@ -2,11 +2,12 @@
  * fo-xsl-formatter.c: Object type for libxslt XSLT processor
  *
  * Copyright (C) 2003 Sun Microsystems
- * Copyright (C) 2007 Menteith Consulting Ltd
+ * Copyright (C) 2007-2008 Menteith Consulting Ltd
  *
  * See COPYING for the status of this software.
  */
 
+#include "config.h"
 #include <string.h>
 #include "fo-utils.h"
 #include "fo-xml-doc-private.h"
@@ -34,6 +35,7 @@ const char *fo_xsl_formatter_error_messages [] = {
   N_("XSLT format failed"),
   N_("Unable to parse stylesheet file: %s"),
   N_("No input result tree specified"),
+  N_("Result tree does not have an XSL-FO root element:: URI: %s; local-name: %s"),
   N_("No area tree present"),
   N_("No output FoDoc specified"),
   N_("Specified FoDoc is not FoDoc object type"),
@@ -45,7 +47,7 @@ const char *fo_xsl_formatter_error_messages [] = {
 
 struct _FoXslFormatter
 {
-  FoObject parent_instance;
+  FoLibfoModule parent_instance;
 
   FoXmlDoc *result_tree;
 
@@ -57,7 +59,7 @@ struct _FoXslFormatter
 
 struct _FoXslFormatterClass
 {
-  FoObjectClass parent_class;
+  FoLibfoModuleClass parent_class;
 };
 
 enum {
@@ -70,6 +72,9 @@ enum {
 
 static void fo_xsl_formatter_class_init   (FoXslFormatterClass *klass);
 static void fo_xsl_formatter_finalize     (GObject             *object);
+
+static const LibfoVersionInfo * _version_info ();
+
 static void fo_xsl_formatter_get_property (GObject             *object,
 					   guint                prop_id,
 					   GValue              *value,
@@ -81,6 +86,17 @@ static void fo_xsl_formatter_set_property (GObject             *object,
 
 static gpointer parent_class;
 
+static LibfoVersionInfo version_info =
+  {
+    LIBFO_MODULE_XSL_FORMATTER,
+    "xsl-formatter",
+    "FoXslFormatter",
+    LIBFO_VERSION,
+    LIBFO_VERSION_STRING,
+    LIBFO_VERSION,
+    LIBFO_VERSION_STRING
+  };
+
 /**
  * fo_xsl_formatter_error_quark:
  * 
@@ -127,7 +143,7 @@ GType fo_xsl_formatter_get_type (void)
 	NULL		/* value_table */
       };
 
-      object_type = g_type_register_static (FO_TYPE_OBJECT,
+      object_type = g_type_register_static (FO_TYPE_LIBFO_MODULE,
                                             "FoXslFormatter",
                                             &object_info, 0);
     }
@@ -145,6 +161,8 @@ void
 fo_xsl_formatter_class_init (FoXslFormatterClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  FoLibfoModuleClass *fo_libfo_module_class =
+    FO_LIBFO_MODULE_CLASS (klass);
 
   parent_class = g_type_class_peek_parent (klass);
 
@@ -152,6 +170,10 @@ fo_xsl_formatter_class_init (FoXslFormatterClass *klass)
   object_class->set_property = fo_xsl_formatter_set_property;
   object_class->finalize     = fo_xsl_formatter_finalize;
 
+  fo_libfo_module_class->version        = libfo_version;
+  fo_libfo_module_class->version_string = libfo_version_string;
+  fo_libfo_module_class->version_info   = _version_info;
+
   g_object_class_install_property
     (object_class,
      PROP_RESULT_TREE,
@@ -224,6 +246,15 @@ fo_xsl_formatter_finalize  (GObject *object)
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
+const LibfoVersionInfo *
+_version_info ()
+{
+  version_info.runtime = libfo_version ();
+  version_info.runtime_string = libfo_version_string ();
+
+  return &version_info;
+}
+
 /**
  * fo_xsl_formatter_get_property:
  * @object:  #GObject whose property will be retreived
@@ -957,6 +988,22 @@ fo_xsl_formatter_format (FoXslFormatter *fo_xsl_formatter,
       return FALSE;
     }
 
+  xmlNodePtr root_element =
+    xmlDocGetRootElement (fo_xml_doc_get_xml_doc (fo_xsl_formatter->result_tree));
+
+  if ((strcmp ((gchar *) root_element->name, "root") != 0) ||
+      (root_element->ns == NULL) ||
+      (strcmp ((gchar *) root_element->ns->href, XSL_FO_NAMESPACE) != 0))
+    {
+      g_set_error (error,
+		   FO_XSL_FORMATTER_ERROR,
+		   FO_XSL_FORMATTER_ERROR_RESULT_TREE_NOT_FO,
+		   _(fo_xsl_formatter_error_messages[FO_XSL_FORMATTER_ERROR_RESULT_TREE_NOT_FO]),
+		   root_element->ns == NULL ? NULL : root_element->ns->href,
+		   root_element->name);
+      return FALSE;
+    }
+
   if (fo_xsl_formatter->fo_doc == NULL)
     {
       g_set_error (error,
@@ -1144,6 +1191,7 @@ fo_xsl_formatter_set_fo_doc (FoXslFormatter *fo_xsl_formatter,
 			     FoDoc          *fo_doc)
 {
   g_return_if_fail (fo_xsl_formatter != NULL);
+  g_return_if_fail (fo_doc != NULL);
 
   if (fo_xsl_formatter->fo_doc != NULL)
     g_object_unref (fo_xsl_formatter->fo_doc);
